@@ -1,6 +1,6 @@
-/*
- * Copyright (c) Members of the EGEE Collaboration. 2006-2010.
- * See http://www.eu-egee.org/partners/ for details on the copyright holders.
+/**
+ * Copyright 2010-2013  Members of the EMI Collaboration.
+ * Copyright 2010-  Stichting Fundamenteel Onderzoek der Materie (FOM-Nikhef)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,6 +13,7 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
+ *
  */
 
 package org.glite.authz.pep.obligation.eesmap;
@@ -52,6 +53,7 @@ import org.opensaml.xacml.policy.EffectType;
 import org.opensaml.xacml.policy.ObligationType;
 import org.opensaml.xacml.policy.ObligationsType;
 import org.opensaml.xml.XMLObjectBuilder;
+import java.util.List;
 
 /**
  * A helper class for converting to/from XACML objects.
@@ -324,6 +326,7 @@ public class XACMLConverter {
         }
 
         Obligation obligation = new Obligation();
+	List<AttributeAssignment> obligationAttributeAssignments = obligation.getAttributeAssignments();
 
         AttributeAssignment attributeAssignment;
         if (xacmlObligation.getAttributeAssignments() != null) {
@@ -333,6 +336,8 @@ public class XACMLConverter {
                         .getAttributeId()));
                 attributeAssignment.setDataType(Strings.safeTrimOrNullString(xacmlAttributeAssignment.getDataType()));
                 attributeAssignment.setValue(Strings.safeTrimOrNullString(xacmlAttributeAssignment.getValue()));
+		// Add attributeAssignments to obligation
+		obligationAttributeAssignments.add(attributeAssignment);
             }
         }
 
@@ -760,4 +765,4 @@ public class XACMLConverter {
 
         return xacmlSubject;
     }
-}
\ No newline at end of file
+}
